@@ -2,7 +2,7 @@ from discordmenu.embed.components import EmbedFooter
 from discordmenu.embed.view_state import ViewState
 from discordmenu.intra_message_state import IntraMessageState
 
-from tsutils.tsubaki import CLOUDFRONT_URL
+from tsutils.tsubaki.links import CLOUDFRONT_URL
 
 TSUBAKI_FLOWER_ICON_URL = CLOUDFRONT_URL + '/tsubaki/tsubakiflower.png'
 
