@@ -7,7 +7,7 @@ import discord
 from discord.ext.commands import Bot
 
 from tsutils.enums import Server
-from tsutils.query_settings.converters import EmbedColor, InvalidArgument
+from tsutils.query_settings.converters import EmbedColor, InvalidArgument, MonsterConverter
 from tsutils.query_settings.enums import AltEvoSort, CardLevelModifier, CardModeModifier, CardPlusModifier, \
     ChildMenuType, EvoGrouping, EvoToFocus, LsMultiplier, MonsterLinkTarget, OrModifierPriority, ShowHelp, SkillDisplay
 
@@ -38,6 +38,7 @@ class QuerySettings:
     }
     NAMES_TO_CONVERTERS = {
         'embedcolor': EmbedColor,
+        'favcard': MonsterConverter,
     }
     SETTINGS_TO_ENUMS = {
         # not serialized
@@ -93,6 +94,7 @@ class QuerySettings:
                  skilldisplay: SkillDisplay = SkillDisplay.skilltexts,
 
                  embedcolor: str = "0",
+                 favcard: str = "0",
                  ):
         self.na_prio = na_prio
         self.ormod_prio = ormod_prio
@@ -109,6 +111,7 @@ class QuerySettings:
         self.skilldisplay = skilldisplay
 
         self._embedcolor = embedcolor
+        self._favcard = favcard
 
     @property
     def embedcolor(self) -> discord.Color:
@@ -119,6 +122,10 @@ class QuerySettings:
         else:
             return discord.Color(int(self._embedcolor))
 
+    @property
+    def favcard(self) -> int:
+        return int(self._favcard)
+
     @classmethod
     def extract(cls, fm_flags: Dict[str, Any], query: str, *, force_valid: bool = False) \
             -> "QuerySettings":
